==> haskell-summoner-tui-2.0.1.1-744.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner-tui.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner-tui
version:              2.0.1.1
visibility:           public
id:                   summoner-tui-2.0.1.1-JUhVFkcjTzDLuF73sftIJx
key:                  summoner-tui-2.0.1.1-JUhVFkcjTzDLuF73sftIJx
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            experimental
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             TUI, TUI Tool, Development
abi:                  6ae3c92799fc9114dcc804d4271c5c34
exposed:              True
exposed-modules:
    Summoner.Tui Summoner.Tui.Field Summoner.Tui.Form
    Summoner.Tui.GroupBorder Summoner.Tui.Kit Summoner.Tui.Validation
    Summoner.Tui.Widget

hidden-modules:       Paths_summoner_tui
import-dirs:          /usr/lib/ghc-9.6.6/site-local/summoner-tui-2.0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/summoner-tui-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/summoner-tui-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner-tui
hs-libraries:         HSsummoner-tui-2.0.1.1-JUhVFkcjTzDLuF73sftIJx
depends:
    base-4.18.2.1 relude-1.2.2.2-KgVg8kiFcZ1L2qmKYg26m0
    brick-0.71.1-JdfqlrLwBnj3lBHnnleSGu
    colourista-0.1.0.2-IcvjUpc9Rbw706VyAKHsEE directory-1.3.8.5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-th-0.4.3.17-IPbJLKFzpBF3M0tXA6bBdw
    summoner-2.0.1.1-Dp9PTEx9qZa9yfqRhtOY6B
    validation-selective-0.2.0.0-KILlRG2ti48J3BGw7UAm1V
    vty-5.39-3q0L5E3i3hsCVn6rztsT8c

haddock-interfaces:
    /usr/share/doc/haskell-summoner-tui/html/summoner-tui.haddock

haddock-html:         /usr/share/doc/haskell-summoner-tui/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-summoner-tui-2.0.1.1-745-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner-tui.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner-tui
version:              2.0.1.1
visibility:           public
id:                   summoner-tui-2.0.1.1-5qUIoBt576I7sJkgQZOjrb
key:                  summoner-tui-2.0.1.1-5qUIoBt576I7sJkgQZOjrb
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            experimental
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             TUI, TUI Tool, Development
abi:                  3916b2717daf6626be081c5cd9f1561c
exposed:              True
exposed-modules:
    Summoner.Tui Summoner.Tui.Field Summoner.Tui.Form
    Summoner.Tui.GroupBorder Summoner.Tui.Kit Summoner.Tui.Validation
    Summoner.Tui.Widget

hidden-modules:       Paths_summoner_tui
import-dirs:          /usr/lib/ghc-9.6.6/site-local/summoner-tui-2.0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/summoner-tui-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/summoner-tui-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner-tui
hs-libraries:         HSsummoner-tui-2.0.1.1-5qUIoBt576I7sJkgQZOjrb
depends:
    base-4.18.2.1 relude-1.2.2.2-9PkKwzJM4Ma4UBkBxLnTrv
    brick-0.71.1-BJUUrBeBQHtJFmTVc5QV2N
    colourista-0.1.0.2-HTbTpLqd7UA3ymn8nCJJVI directory-1.3.8.5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-th-0.4.3.17-IPbJLKFzpBF3M0tXA6bBdw
    summoner-2.0.1.1-1fuWLtcMOqD2WXN8TaVq3o
    validation-selective-0.2.0.0-3ecfd9K5DIA1eGBn8v2bT
    vty-5.39-9xS8jpTHaH7EHMu4aXKdNZ

haddock-interfaces:
    /usr/share/doc/haskell-summoner-tui/html/summoner-tui.haddock

haddock-html:         /usr/share/doc/haskell-summoner-tui/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
